summaryrefslogtreecommitdiffstats
path: root/item_updater.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'item_updater.hpp')
-rw-r--r--item_updater.hpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/item_updater.hpp b/item_updater.hpp
index ac966ca..aafd66b 100644
--- a/item_updater.hpp
+++ b/item_updater.hpp
@@ -106,11 +106,11 @@ class ItemUpdater : public ItemUpdaterInherit
*/
void createActiveAssociation(const std::string& path);
/** @brief Removes an active association to the software image
*
* @param[in] path - The path to remove the association from.
*/
- void removeActiveAssociation(const std::string& path);
+ void removeAssociations(const std::string& path);
/** @brief Determine if the given priority is the lowest
*
OpenPOWER on IntegriCloud
@@ -106,11 +106,11 @@ class ItemUpdater : public ItemUpdaterInherit
*/
void createActiveAssociation(const std::string& path);
- /** @brief Removes an active association to the software image
+ /** @brief Removes the associations from the provided software image path
*
@@ -106,11 +106,11 @@ class ItemUpdater : public ItemUpdaterInherit
*
- * @param[in] path - The path to remove the association from.
+ * @param[in] path - The path to remove the associations from.
*/